@@ -3,5 +3,8 @@
 from .RecordableIterator import RecordableIterator
 from .RingBuffer import RingBuffer
 from .SumIterator import SumIterator
+from .AsyncMethod import AsyncMethod
 from .BufferedIterator import BufferedIterator
 from .BitsWidthConvertIterator import BitsWidthConvertIterator
+from .AverageInterator import AverageInterator
+
